//
//  BuoyDetallViewController.m
//  Buoys
//
//  Created by Fernando Pérez López on 18/05/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "BuoyDetallViewController.h"
#import "DisplayMap.h"
#import "DataDetallView.h"


@implementation BuoyDetallViewController

@synthesize selectedBuoy,mapView,buoyPositions;



- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)dealloc
{
    [selectedBuoy release];
    [mapView release];
    [buoyPositions release];
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
    
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    //ponemos mapa satelite
    self.mapView.mapType = MKMapTypeSatellite;
    
    
    
    buoyPositions = [[NSMutableArray alloc] init];
    
    
    //Cargamos plist desde local
   // NSString *path=[[NSBundle mainBundle] pathForResource:@"buoys" ofType:@"plist"];
    
    //add para descargado de la web
    NSString *docsDir = [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject];
    NSString *file = @"buoys.plist";
    NSString* path = [docsDir stringByAppendingPathComponent: file];
    
    NSMutableArray  *plistData = [[NSMutableArray arrayWithContentsOfFile:path]retain];
    
    
     
    
    //leemos plist
    for(NSDictionary *dict in plistData) {
        
        
        NSString *value;
        value = [dict objectForKey:@"Buoy"];
        
        //Si encontramos boya seleccionada leemos datos
        if ([value isEqualToString:selectedBuoy]) {
            
            buoyPositions = [dict objectForKey:@"Measures"];
            
            
            double minLat = [[buoyPositions valueForKeyPath:@"@min.Latitude"] doubleValue];
            double maxLat = [[buoyPositions valueForKeyPath:@"@max.Latitude"] doubleValue];
            double minLon = [[buoyPositions valueForKeyPath:@"@min.Longitude"] doubleValue];
            double maxLon = [[buoyPositions valueForKeyPath:@"@max.Longitude"] doubleValue];
            
            MKCoordinateRegion region;
            region.center.latitude = (maxLat + minLat) / 2.0;
            region.center.longitude = (maxLon + minLon) / 2.0;
            region.span.latitudeDelta = (maxLat - minLat) * 3.05;
            region.span.longitudeDelta = (maxLon - minLon) * 3.05;
            mapView.region = region;
            
             
            
            
            //Mostramos datos medidas
            for (NSDictionary *dictMeasures in buoyPositions) {
                
                DisplayMap *measure = [[DisplayMap alloc] initWithDictionary:dictMeasures];
                [mapView addAnnotation:measure];
                [measure release];
                
                
            }

            

        }
    }
        

    
    self.navigationItem.title = [NSString stringWithFormat: @"Buoy: %@",selectedBuoy];
}


- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id <MKAnnotation>)annotation{
	
	
    
    
    MKPinAnnotationView *pinView = nil; 
    if(annotation != self.mapView.userLocation) 
    {
        static NSString *defaultPinID = @"com.invasivecode.pin";
        pinView = (MKPinAnnotationView *)[self.mapView dequeueReusableAnnotationViewWithIdentifier:defaultPinID];
        if ( pinView == nil ) pinView = [[[MKPinAnnotationView alloc]
                                          initWithAnnotation:annotation reuseIdentifier:defaultPinID] autorelease];
        
        pinView.pinColor = MKPinAnnotationColorRed; 
        pinView.canShowCallout = YES;
        pinView.animatesDrop = YES;
        
        
        
        pinView.rightCalloutAccessoryView = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
        
        
        self.mapView.delegate=self;


    } 
    else {
        [self.mapView.userLocation setTitle:@"I am here"];
    }
    return pinView;
    
    
    
    
    
}





// Localizacion usuario mapa
-(IBAction)getLocation {
   
    
	
	mapView.showsUserLocation = YES;
	
        
	MKUserLocation *ulocation = [[MKUserLocation alloc] init]; 
    
   CLLocationCoordinate2D userLoc;
    
    
    MKCoordinateRegion regionLocation;
    
    userLoc = ulocation.location.coordinate;
    
    regionLocation.center = userLoc;
    regionLocation.span.latitudeDelta = 60.0;
    regionLocation.span.longitudeDelta = 120.0;
    
    [self.mapView setRegion:regionLocation animated:YES];
        
    
    
    

       
   

	    
            
}



// Tipos de mapa a escoger
-(IBAction)setMap:(id)sender {
    switch (((UISegmentedControl *) sender).selectedSegmentIndex) {
        case 0:
            mapView.mapType = MKMapTypeStandard;
            break;
            
        case 1:
            mapView.mapType = MKMapTypeSatellite;
            break;
        default:
            break;
    }
}



- (void)mapView:(MKMapView *)mapView annotationView:(MKAnnotationView *)view calloutAccessoryControlTapped:(UIControl *)control
{
	
    DataDetallView *dataDetallView = [[DataDetallView alloc] initWithNibName:@"DataDetallView" bundle:nil];
    
    DisplayMap *displayMap = (DisplayMap *) view.annotation;
    
    
    dataDetallView.selectedBuoy = self.selectedBuoy;
    dataDetallView.latitude = displayMap.latitude;
    dataDetallView.longitude = displayMap.longitude;
    dataDetallView.date = displayMap.date;
    dataDetallView.temperature = displayMap.temperature;
    dataDetallView.conductivity = displayMap.conductivity;
    dataDetallView.salinity = displayMap.salinity;
    
    [self.navigationController pushViewController:dataDetallView animated:YES];
    [dataDetallView release];
	dataDetallView = nil;
    
   // NSLog(@"I've been tapped");
}












- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
